==> digiclockwdg_0.3.1-2.tar.gz: digiclockwdg-0.3.1/digiclock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation>Paramètres de &quot;DigiClock&quot;</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation>Couleur des chiffres</translation>
    </message>
    <message>
        <source>24H</source>
        <translation>24 Heures</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation>12 Heures (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation>Militaire</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation>Défaut (LCD)</translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation>A propos de &quot;DigiClock&quot;</translation>
    </message>
    <message>
        <source>B</source>
        <translation>Gras</translation>
    </message>
    <message>
        <source>I</source>
        <translation>Italique</translation>
    </message>
    <message>
        <source>12:48</source>
        <translation></translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Secondes</translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation>Glinote</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation>Fuseau</translation>
    </message>
    <message>
        <source>&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing digital time</source>
        <translation>&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Utilise &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Widget sur le bureau  qui affiche l&apos;heure en format digital&lt;br&gt;&lt;br&gt;Traduction: Gary delaMer</translation>
    </message>
</context>
</TS>

==> digiclockwdg_0.4.1.tar.gz: digiclockwdg-0.4.1/digiclock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation>Paramètres de &quot;DigiClock&quot;</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation>Couleur des chiffres</translation>
    </message>
    <message>
        <source>24H</source>
        <translation>24 Heures</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation>12 Heures (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation>Militaire</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation>Défaut (LCD)</translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation>A propos de &quot;DigiClock&quot;</translation>
    </message>
    <message>
        <source>B</source>
        <translation>Gras</translation>
    </message>
    <message>
        <source>I</source>
        <translation>Italique</translation>
    </message>
    <message>
        <source>12:48</source>
        <translation></translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>Transparency</source>
        <translation>Transparence</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Secondes</translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation>Clignote</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation>Fuseau</translation>
    </message>
    <message>
        <source>Show City</source>
        <translation>Voir la ville</translation>
    </message>
    <message>
        <source>Open Clock app on Click</source>
        <translation>Cliquer ouvre l&apos;appli Horloge</translation>
    </message>
    <message>
        <source>Rotate on Accel</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <source>DigiClock</source>
        <translation>Couleur des chiffres</translation>
    </message>
    <message>
        <source>Developed with</source>
        <translation>Développé avec</translation>
    </message>
    <message>
        <source>Desktop widget, showing digital time</source>
        <translation>Widget sur le bureau qui affiche l&apos;heure au format digital</translation>
    </message>
    <message>
        <source>Send reports to:</source>
        <translation>Envoyé le rapport à:</translation>
    </message>
</context>
</TS>
